# Generated by roxygen2: do not edit by hand

export(calcMetrics)
export(clustByHood)
export(findNearCells)
export(mergeByGroup)
export(mergeHoodSpe)
export(perplexityPermute)
export(plotColocal)
export(plotHoodMat)
export(plotProbDist)
export(plotTissue)
export(readHoodData)
export(scanHoods)
import(Rcpp)
import(SpatialExperiment)
import(ggplot2)
import(knitr)
importFrom(SummarizedExperiment,assay)
importFrom(SummarizedExperiment,colData)
importFrom(grid,gpar)
importFrom(grid,unit)
importFrom(methods,is)
importFrom(rmarkdown,draft)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,cor)
importFrom(stats,median)
importFrom(stats,reshape)
importFrom(utils,globalVariables)
useDynLib(hoodscanR)
