# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

calculate_metrics <- function(probs) {
    .Call('_hoodscanR_calculate_metrics', PACKAGE = 'hoodscanR', probs)
}

